#
# spec file for package python-bindep
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-bindep
Version:        2.11.0
Release:        3.4
Summary:        Binary dependency utility
License:        Apache-2.0
URL:            https://docs.opendev.org/opendev/bindep
Source:         https://files.pythonhosted.org/packages/source/b/bindep/bindep-%{version}.tar.gz
Patch0:         remove-mock.patch
BuildRequires:  %{python_module pbr}
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module distro >= 1.7.0}
BuildRequires:  %{python_module Parsley}
BuildRequires:  %{python_module coverage >= 3.6}
BuildRequires:  %{python_module fixtures >= 0.3.12}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pbr >= 2.0.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-subunit}
BuildRequires:  %{python_module testrepository >= 0.0.13}
BuildRequires:  %{python_module testtools >= 0.9.27}
BuildRequires:  %{python_module wheel}
# /SECTION
BuildRequires:  fdupes
BuildRequires:  openSUSE-release
Requires:       python-Parsley
Requires:       python-distro >= 1.7.0
Requires:       python-packaging
Requires:       python-pbr >= 2.0.0
Suggests:       python-distro < 1.7.0
Suggests:       python-packaging < 21.0
BuildArch:      noarch
%python_subpackages

%description
Bindep is a tool for checking the presence of binary packages needed to
use an application / library. It started life as a way to make it easier to set
up a development environment for OpenStack projects. While OpenStack depends
heavily on `pip` for installation of Python dependencies, some dependencies are
not Python based, and particularly for testing, some dependencies have to be
installed before `pip` can be used - such as `virtualenv` and `pip` itself.

%prep
%autosetup -p1 -n bindep-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/bindep
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -s -k 'not (test_arch_implies_pacman or test_manjaro_implies_pacman)'

%post
%python_install_alternative bindep

%postun
%python_uninstall_alternative bindep

%files %{python_files}
%doc AUTHORS ChangeLog NEWS.rst README.rst
%license LICENSE
%python_alternative %{_bindir}/bindep
%{python_sitelib}/bindep
%{python_sitelib}/bindep-%{version}*info

%changelog
* Fri May  5 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Mon Mar 27 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch remove-mock.patch:
  * Remove use of external mock module, try unittest.mock first.
- Switch to pyproject macros.
- Actually run the testsuite using pytest.
- Stop using %%python_sitelib/*
* Tue Mar 21 2023 Johannes Kastl <kastl@b1-systems.de>
- recreate spec file using py2pack
* Fri Sep 23 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 2.11.0
  * Add support for Rocky Linux and Manjaro to Bindep.
* Tue Jan 11 2022 Dirk Müller <dmueller@suse.com>
- add python-rpm-macros dependency
* Tue Jan  4 2022 Dirk Müller <dmueller@suse.com>
- update to 2.10.1:
  * Add old python packaging pin
  * Add release note for rocky and manjaro
  * feat: Add test support for Manjaro Linux
  * feat: Add support for Manjaro Linux
  * Require packaging
  * Add Rocky Linux support
  * Correctly skip sdist building in tox.ini
  * Fix formatting issues in docs
  * Build releases on ubuntu-focal
  * Update contributor doc and readme
  * Overhaul Python package metadata
  * Remove release note about rpm path references
  * Build docs for OpenDev
  * Move all jobs in-repo
  * Publish release notes
  * Add missing release notes
  * Assure bindep can be called as a module
  * ArchLinux: ignore unrelated warnings from pacman
  * Fixed pep8 job
  * Add centos 8 and focal testing
  * Cull the test bindep file
  * Use abstracted virtualenv\_command from ensure-pip
  * Tolerate missing bindep.txt when using --profiles
  * Add OracleLinux support
  * Fix test execution failure on Darwin
  * Expose base python version as an atom
  * Fix emerge testcases
  * Replace Trusty with Bionic in the testing
  * Some cleanups
  * Add bindep.txt for pypy
  * Change openstack-dev to openstack-discuss
  * Add dependency version examples to README
  * Switch to opensuse-15 nodeset for bindep testing
  * Use Python 3.x by default for testing
  * OpenDev Migration Patch
  * Adds job to test bindep on Fedora
  * Fix bindep --brief for arch linux
  * Replace deprecated bindep-fallback testing
  * Allow mentioning tools paths in bindep
  * Fix apk handling of warnings/output problems
  * Add openSUSE 15.0 testing
  * Update docs building
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Nov 30 2018 Thomas Bechtold <tbechtold@suse.com>
- update to 2.8.1:
  * Remove fedora-27 fallback job
  * Fix bindep path
  * Fix user profile display
  * Add opensuse-leap support
  * Add support for Alpine Linux
  * Clearer unsupported platform error message
  * Use the distro package to determine distro
  * Move to argparse
  * Remove debian-jessie nodeset
  * SUSE: Update openSUSE Tumbleweed references for lsb-release-3.X.X
  * Update to fedora-27 for testing
  * add detection of darwin (MacOS/OSX)
  * Move jenkins/data/bindep-fallback.txt
  * add support for rhel workstation
  * Zuul: Remove project name
  * Add native Zuul v3 bindep-fallback test
  * Fix logic for groups
  * Add new syntax to allow matching multiple profile
  * Add ability to list all deps
  * bindep: Query for RPM capabilities as well
  * Log an error when lsb\_release cannot be executed
  * Fix test\_main and test\_depends for systems missing lsb\_release
  * Handle dotted versions in platform selectors
  * Update tox.ini with py35
  * bindep: depends: Add distro family aliases
  * Add Amazon Linux support to bindep
  * Consistently check subprocess output
  * Update 'pbr' version requirements
  * Exit the loop when we don't have a package
  * bindep: depends: Add support for openSUSE {Leap,Tumbleweed}
  * Bump lower cap of PBR to 1.3
  * Extract file finding and processing to functions
  * Add RHEL support
  * get\_pkg\_version: Fix py3 bytes/str errors
  * Use the autodoc Sphinx extension
  * Move dev reference from readme to contributing
  * Remove unused module index in documentation
  * Removed remnants of support\_py26 module
  * Give some examples
  * Update newsfile entry for default filename change
  * Update a couple of old references in README file
  * Add bindep.txt as default filename
  * Build universal wheels
  * Add '\_' to the list of valid characters acceptable in package name
  * Remove discover from test-requirements
- Switch to singlespec
- Use %%license
- Drop unused BuildRequires
* Wed Jul 20 2016 tbechtold@suse.com
- Initial packaging (version 2.0.0)
